# chts2012ithim2016-03-02.R  N Maizlish  3/1/2016
# Reads CHTS2011 household, person, and place files and
# calculates distances and times traveled by mode

# set working directory
setwd ('C:/SASUniversityEdition/myfolders/ITHIM/TravelSurveys/CalTRANS/CHTS2012')
# Get todays date to assign version
# today <- Sys.Date()
today <- date()

# turn off scientific notation
options(scipen=999)

# Read county FIPS file
county_fips <-read.csv(file= "CA_County_FIPS2Region2010.csv", head=TRUE, sep=",")
# Rename county FIPS code
names(county_fips)[names(county_fips)=="county_fips"] <-"ctfip"
county_fips <- county_fips[, c("ctfip","countyname","megaregion_name","megaregion_code")]

########################### Households File #####################
households <- read.csv(file= "hh_sm.csv", head=TRUE, sep=",", na.strings=c("NA"))

# Rename and keep variables of interest
households <- households[, c("sampno", "ctfip")]

# merge files 
households <- merge(households, county_fips, by="ctfip", all.x=TRUE)

########################### Persons File #####################
person <- read.csv(file= "person_sm.csv", head=TRUE, sep=",", na.strings=c("NA"))

# Keep variables of interest
names(person)[names(person)=="sampn"] <- "sampno"

# create person_id
person$person_id <- paste0(person$sampno,person$perno)

# Save variables of interest
person <- person[, c("sampno", "perno", "person_id","gend","age_imputed", "perwgt", "expperwgt")]

# recode missing gender
person$gend[person$gend == 9] <-NA

# Create ITHIM age categories
person$age8cat <- NA
person$age8cat <-cut(person$age_imputed,breaks=c(0,5,15,30,45,60,70,80,100),labels=c("00-04","05-14","15-29","30-44","45-59","60-69","70-79", "80+"), right=FALSE)

nrow(person)
# merge person file with household files to pick up region/county
person <- merge(person,households, by ="sampno", all.x = TRUE)
nrow(person)


########################### Trip File #####################
trip <- read.csv(file= "survey_place.csv", head=TRUE, sep=",", na.strings=c("NA"))

# keep variables of interest
trip <-trip[,c("sampno", "perno", "plano", "tripno", "mode", "trip_distance_miles", "air_trip_distance_miles", "tripdistanceflag", "prev_trip_duration_min", "county_id", "city", "zipcode", "state", "parked_minutes", "tcf", "tcfperwgt", "exptcfperwgt")]

# Delete non trips (no sample weight)
trip <- subset(trip, trip$tcf != "NA")

# merge with ITHIM mode look-up table 
mode <- read.csv(file= "lookup_ithim_mode.csv", head=TRUE, sep=",", na.strings=c("NA"))
trip <- merge(trip, mode, by="mode", all.x=TRUE)

################# Data Quality Edits #######################
# For trips with complete time and distance, identify outliers 
# based on their speed 
# for trips > 0 miles and > 0 minutes (non loop trips)

# Unlikely speed threshold for a single trip Unlikely distance 
# threshold for a single trip of 8 hours duration
#            Maximum Speed   Max.Daily Distance at ave speed/8 hrs)
# ---------------------------------------
# Mode       mph   mi/min  ave. mph miles 
# Walk       8.4    0.14        3    24
# Bike        24    0.40       12    92
# Car         75    1.25       60   480
# Bus         75    1.25       45   200
# Rail        75    1.25       45   200
# Motorcycle  75    1.25       60   460

#################### All Modes #################
# Create trip speed for every mode
trip$mi_per_min <- trip$trip_distance_miles/trip$prev_trip_duration_min

# if trip_distance is missing but air_distance is not, replace
# replace missing trip distance with straight line distance
trip$trip_distance_miles <-ifelse(is.na(trip$trip_distance_miles), trip$air_trip_distance_miles, trip$trip_distance_miles)

# replace 0 trip distances with straight line distance
# when air_trip_distances are not 0
trip$trip_distance_miles <-ifelse(trip$trip_distance_miles==0 & trip$air_trip_distance_miles > 0, trip$air_trip_distance_miles, trip$trip_distance_miles)

#################### Walk Outliers #############################

# if walk speed exceeds 8.4 mph (0.14 mi/min), shorten trip distance to 
# straight line distance (includes fast, long-trip "hikers" in Inyo Co.)

trip$new_trip_distance_miles =ifelse(trip$mi_per_min > 0.14 & trip$air_trip_distance_miles < trip$trip_distance_miles & trip$air_trip_distance_miles >0 & trip$mode_name=="Walk", trip$air_trip_distance_miles, trip$trip_distance_miles)

# Recalculate speed, 
trip$new_mi_per_min <- trip$new_trip_distance_miles/ trip$prev_trip_duration_min

# and if trip speed still is > 8.4 mph, 
# recalculate trip duration based on maximum reasonable speed
trip$tripdur = ifelse(trip$new_mi_per_min > 0.14 & trip$mode_name=="Walk",trip$new_trip_distance_miles/.14,trip$prev_trip_duration_min)

# Recalculate speed to check none is > 8.4 mph 
trip$check_mi_per_min <- NA
trip$check_mi_per_min <- ifelse(trip$mode_name=="Walk",trip$new_trip_distance_miles/trip$tripdur, trip$check_mi_per_min)

# Add in loop trips (distance = 0, trip duration > 0) 
# using mean of non-loop trips 0.04485145 mi/min = 2.69 mph

mean_walk_speed <- mean(trip$check_mi_per_min[trip$mode_name=="Walk"],na.rm=TRUE)
mean_walk_speed

trip$looptrip <- ifelse(trip$trip_distance_miles==0 & trip$prev_trip_duration_min >0, "Loop", "No")

# Count of loop trips by mode
table(trip$looptrip,trip$mode_name)
      
#     Bike Bus Car-driver Car-pass. Ferry Motorcyc. Plane Rail Unkn. Walk
# Loop  27  18      295     70        0       5      1      12   0    760
# No  6340 10331 196709  88811       96     997      538  3414   0  43320

trip$new_trip_distance_miles <- ifelse(trip$new_trip_distance_miles==0 & trip$trip_distance_miles==0 & trip$tripdur >0 & trip$mode_name=="Walk", trip$prev_trip_duration_min* mean_walk_speed, trip$new_trip_distance_miles)

# Recalculate mean walk speed with loop trips
trip$check_mi_per_min = trip$new_trip_distance_miles/trip$tripdur
mean_walk_speed2 <- mean(trip$check_mi_per_min[trip$mode_name=="Walk"],na.rm=TRUE)

# New mean walk speed 0.04562475 mi/min or 2.73 mph
mean_walk_speed2

# Subset rows which have a car park walking (98=DK and 99=Refused omitted
# 0 minutes of walking also excluded
car_park_walk <-subset(trip,(trip$mode_name=="Car-driver" | trip$mode_name=="Car-passenger") & (trip$parked_minutes >0 & trip$parked_minutes <98))

# assign a trip number by adding .5 to existing trip number
car_park_walk$tripno = car_park_walk$tripno + 0.5

# Makes sure original time and distances are nulled out
car_park_walk$trip_distance_miles <- NA
car_park_walk$air_trip_distance_miles <- NA
car_park_walk$prev_trip_duration_min <- NA

# Change mode to walk (from car)
car_park_walk$mode_name <- "Walk"
car_park_walk$mode_description <- "Walk from parking"
car_park_walk$mode_code <- 1
car_park_walk$mode <- 1

# Assign parked_minutes to trip duration
car_park_walk$tripdur <- car_park_walk$parked_minutes

# Assign average speed of walking to mi_per_minute, new_mi_per_min check_mi_per_min
car_park_walk$mi_per_min <- mean_walk_speed2
car_park_walk$new_mi_per_min <- mean_walk_speed2
car_park_walk$check_mi_per_min <- mean_walk_speed2

# Assign new_trip_distance based on walkspeed2
# Multiply by 2 to account walk to destination and back to car park
car_park_walk$new_trip_distance_miles <- 2*car_park_walk$tripdur * mean_walk_speed2

# add rows back to trip file
trip <- rbind(trip,car_park_walk)

# Count number of trips that have a distance, but no duration and
# trips that don't have a distance, but do have a duration
# Returns 0 rows
sum(is.na(trip$trip_distance_miles) & !is.na(trip$prev_trip_duration_min))
sum(!is.na(trip$trip_distance_miles) & is.na(trip$prev_trip_duration_min))


########### Data Quality Notes #############
# Sacramento Area in CHTS2012 has a per capita mean walk distance that is 0.13 vs. .35 in NHTS2009.  Compared to NHTS2009, CHTS2012 walk means are consistently lower by 0. 121 miles (excluding Savramento area. So the walk to bike ratio in Sacramento is not <1 (implausible), the Sacramento Area walk mean was bias corrected from the NHTS2009 value (.0.352765 - 0.121336 = 0.231429498 (with a walk:bike distance ratio of 1.39)


#################### Bike Outliers #############################

# if bike speed exceeds 24 mph. shorten trip distance to 
# straight line distance 

trip$new_trip_distance_miles = ifelse(trip$mi_per_min > 0.4 & trip$air_trip_distance_miles < trip$trip_distance_miles & trip$air_trip_distance_miles >0 & trip$mode_name=="Bike", trip$air_trip_distance_miles, trip$new_trip_distance_miles)

# Recalculate speed, and if still is > 24 mph, reset trip duration
trip$new_mi_per_min <- ifelse(trip$mode_name=="Bike",trip$new_trip_distance_miles/ trip$prev_trip_duration_min, trip$check_mi_per_min)

trip$tripdur = ifelse(trip$new_mi_per_min > 0.4 & trip$mode_name=="Bike",trip$new_trip_distance_miles/.4,trip$tripdur)

# Recalculate speed to check none is > 24 mph
trip$check_mi_per_min <- ifelse(trip$mode_name=="Bike",trip$new_trip_distance_miles/trip$tripdur, trip$check_mi_per_min)

# Add in loop trips (distance = 0, trip duration > 0) 
# using mean of non-loop trips 0.1102182 mi/min = 6.61 mph
mean_bike_speed <- mean(trip$check_mi_per_min[trip$mode_name=="Bike"],na.rm=TRUE)
mean_bike_speed

trip$looptrip <- ifelse(trip$trip_distance_miles==0 & trip$prev_trip_duration_min >0 & trip$mode_name=="Bike", "Loop", trip$looptrip)

trip$new_trip_distance_miles <- ifelse(trip$new_trip_distance_miles==0 & trip$trip_distance_miles==0 & trip$tripdur >0 & trip$mode_name=="Bike", trip$prev_trip_duration_min* mean_bike_speed, trip$new_trip_distance_miles)

# Recalculate mean bike speed with loop trips
trip$check_mi_per_min = trip$new_trip_distance_miles/trip$tripdur
mean_bike_speed2 <- mean(trip$check_mi_per_min[trip$mode_name=="Bike"],na.rm=TRUE)

# New mean bike speed 0.1106856  mi/min or 6.64  mph
mean_bike_speed2

# Sacramento Area outlier sampno 14247051 perno 1
# Distance
trip$new_trip_distance_miles[trip$sampno==1424705 & trip$perno==1 & trip$mode_name=="Bike"] <- 0
# Time
trip$tripdur[trip$sampno==1424705 & trip$perno==1 & trip$mode_name=="Bike"] <- 0

#################### Car-driver Outliers #############################

# if car-driver speed exceeds 75 mph. shorten trip distance to 
# straight line distance 

trip$new_trip_distance_miles = ifelse(trip$mi_per_min > 1.25 & trip$air_trip_distance_miles < trip$trip_distance_miles & trip$air_trip_distance_miles >0 & trip$mode_name=="Car-driver", trip$air_trip_distance_miles, trip$new_trip_distance_miles)

# Recalculate speed, and if still is > 75 mph, reset trip duration
trip$new_mi_per_min <- ifelse(trip$mode_name=="Car-driver",trip$new_trip_distance_miles/ trip$prev_trip_duration_min, trip$check_mi_per_min)

trip$tripdur = ifelse(trip$new_mi_per_min > 1.25 & trip$mode_name=="Car-driver",trip$new_trip_distance_miles/1.25,trip$tripdur)

# Recalculate speed to check none is > 75 mph
trip$check_mi_per_min <- ifelse(trip$mode_name=="Car-driver",trip$new_trip_distance_miles/trip$tripdur, trip$check_mi_per_min)

# Add in loop trips (distance = 0, trip duration > 0) 
# using mean of non-loop trips 0.3634113 mi/min = 21.8 mph

mean_car_driver_speed <- mean(trip$check_mi_per_min[trip$mode_name=="Car-driver"],na.rm=TRUE)
mean_car_driver_speed

trip$looptrip <- ifelse(trip$trip_distance_miles==0 & trip$prev_trip_duration_min >0 & trip$mode_name=="Car-driver", "Loop", trip$looptrip)

trip$new_trip_distance_miles <- ifelse(trip$new_trip_distance_miles==0 & trip$trip_distance_miles==0 & trip$tripdur >0 & trip$mode_name=="Car-Driver", trip$prev_trip_duration_min* mean_car_driver_speed, trip$new_trip_distance_miles)

# Recalculate mean car speed with loop trips
trip$check_mi_per_min = trip$new_trip_distance_miles/trip$tripdur
mean_car_driver_speed2 <- mean(trip$check_mi_per_min[trip$mode_name=="Car-driver"],na.rm=TRUE)

# New mean car speed 0.3634113 mi/min = 21.8 mph 
mean_car_driver_speed2

#################### Car-passenger Outliers #############################

# if Car-passenger speed exceeds 75 mph. shorten trip distance to 
# straight line distance 

trip$new_trip_distance_miles = ifelse(trip$mi_per_min > 1.25 & trip$air_trip_distance_miles < trip$trip_distance_miles & trip$air_trip_distance_miles >0 & trip$mode_name=="Car-passenger", trip$air_trip_distance_miles, trip$new_trip_distance_miles)

# Recalculate speed, and if still is > 75 mph, reset trip duration
trip$new_mi_per_min <- ifelse(trip$mode_name=="Car-passenger",trip$new_trip_distance_miles/ trip$prev_trip_duration_min, trip$check_mi_per_min)

trip$tripdur = ifelse(trip$new_mi_per_min > 1.25 & trip$mode_name=="Car-passenger",trip$new_trip_distance_miles/1.25,trip$tripdur)

# Recalculate speed to check none is > 75 mph
trip$check_mi_per_min <- ifelse(trip$mode_name=="Car-passenger",trip$new_trip_distance_miles/trip$tripdur, trip$check_mi_per_min)

########### Add in loop trips (distance = 0, trip duration > 0) 
# using mean of non-loop trips 0.3573937 mi/min or 21.4 mph

mean_car_passenger_speed <- mean(trip$check_mi_per_min[trip$mode_name=="Car-passenger"],na.rm=TRUE)
mean_car_passenger_speed

trip$looptrip <- ifelse(trip$trip_distance_miles==0 & trip$prev_trip_duration_min >0 & trip$mode_name=="Car-passenger", "Loop", trip$looptrip)

trip$new_trip_distance_miles <- ifelse(trip$new_trip_distance_miles==0 & trip$trip_distance_miles==0 & trip$tripdur >0 & trip$mode_name=="Car-passenger", trip$prev_trip_duration_min* mean_car_passenger_speed, trip$new_trip_distance_miles)

# Recalculate mean car speed with loop trips
trip$check_mi_per_min = trip$new_trip_distance_miles/trip$tripdur
mean_car_passenger_speed2 <- mean(trip$check_mi_per_min[trip$mode_name=="Car-passenger"],na.rm=TRUE)

# New mean car speed 0.3576752 mi/min or 21.4  mph
mean_car_passenger_speed2

#################### Motorcyle Outliers #############################

# if Motorcycle speed exceeds 75 mph. shorten trip distance to 
# straight line distance 

trip$new_trip_distance_miles = ifelse(trip$mi_per_min > 1.25 & trip$air_trip_distance_miles < trip$trip_distance_miles & trip$air_trip_distance_miles >0 & trip$mode_name=="Motorcycle", trip$air_trip_distance_miles, trip$new_trip_distance_miles)

# Recalculate speed, and if still is > 75 mph, reset trip duration
trip$new_mi_per_min <- ifelse(trip$mode_name=="Motorcycle",trip$new_trip_distance_miles/ trip$prev_trip_duration_min, trip$check_mi_per_min)

trip$tripdur = ifelse(trip$new_mi_per_min > 1.25 & trip$mode_name=="Motorcycle",trip$new_trip_distance_miles/1.25,trip$tripdur)

# Recalculate speed to check none is > 75 mph
trip$check_mi_per_min <- ifelse(trip$mode_name=="Motorcycle",trip$new_trip_distance_miles/trip$tripdur, trip$check_mi_per_min)

# Add in loop trips (distance = 0, trip duration > 0) 
# using mean of non-loop trips 0.3937974  mi/min = 23.6 mph

mean_motorcycle_speed <- mean(trip$check_mi_per_min[trip$mode_name=="Motorcycle"],na.rm=TRUE)
mean_motorcycle_speed

trip$looptrip <- ifelse(trip$trip_distance_miles==0 & trip$prev_trip_duration_min >0 & trip$mode_name=="Motorcycle", "Loop", trip$looptrip)

trip$new_trip_distance_miles <- ifelse(trip$new_trip_distance_miles==0 & trip$trip_distance_miles==0 & trip$tripdur >0 & trip$mode_name=="Motorcycle", trip$prev_trip_duration_min* mean_motorcycle_speed, trip$new_trip_distance_miles)

# Recalculate mean motorcycle speed with loop trips
trip$check_mi_per_min = trip$new_trip_distance_miles/trip$tripdur
mean_motorcycle_speed2 <- mean(trip$check_mi_per_min[trip$mode_name=="Motorcycle"],na.rm=TRUE)

# New mean motorcycle speed 0.3957625 mi/min or 23.7 mph
mean_motorcycle_speed2

#################### Bus Outliers #############################

# if Bus speed exceeds 75 mph. shorten trip distance to 
# straight line distance 

trip$new_trip_distance_miles = ifelse(trip$mi_per_min > 1.25 & trip$air_trip_distance_miles < trip$trip_distance_miles & trip$air_trip_distance_miles >0 & trip$mode_name=="Bus", trip$air_trip_distance_miles, trip$new_trip_distance_miles)

# Recalculate speed, and if still is > 75 mph, reset trip duration
trip$new_mi_per_min <- ifelse(trip$mode_name=="Bus",trip$new_trip_distance_miles/ trip$prev_trip_duration_min, trip$check_mi_per_min)

trip$tripdur = ifelse(trip$new_mi_per_min > 1.25 & trip$mode_name=="Bus",trip$new_trip_distance_miles/1.25,trip$tripdur)

# Recalculate speed to check none is > 75 mph
trip$check_mi_per_min <- ifelse(trip$mode_name=="Bus",trip$new_trip_distance_miles/trip$tripdur, trip$check_mi_per_min)

# Add in loop trips (distance = 0, trip duration > 0) 
# using mean of non-loop trips 0.2313945 mi/min = 13.9 mph

mean_bus_speed <- mean(trip$check_mi_per_min[trip$mode_name=="Bus"],na.rm=TRUE)

mean_bus_speed

trip$looptrip <- ifelse(trip$trip_distance_miles==0 & trip$prev_trip_duration_min >0 & trip$mode_name=="Bus", "Loop", trip$looptrip)

trip$new_trip_distance_miles <- ifelse(trip$new_trip_distance_miles==0 & trip$trip_distance_miles==0 & trip$tripdur >0 & trip$mode_name=="Bus", trip$prev_trip_duration_min* mean_bus_speed, trip$new_trip_distance_miles)

# Recalculate mean bus speed with loop trips
trip$check_mi_per_min = trip$new_trip_distance_miles/trip$tripdur

mean_bus_speed2 <- mean(trip$check_mi_per_min[trip$mode_name=="Bus"],na.rm=TRUE)

# New mean bus speed 0.2317969 mi/min or 13.9 mph
mean_bus_speed2


#################### Rail Outliers #############################

# if Rail speed exceeds 75 mph. shorten trip distance to 
# straight line distance
# 2 interstate rail trips (Washington State and IL) not ecluded

trip$new_trip_distance_miles = ifelse(trip$mi_per_min > 1.25 & trip$air_trip_distance_miles < trip$trip_distance_miles & trip$air_trip_distance_miles >0 & trip$mode_name=="Rail", trip$air_trip_distance_miles, trip$new_trip_distance_miles)

# Recalculate speed, and if still is > 75 mph, reset trip duration
trip$new_mi_per_min <- ifelse(trip$mode_name=="Rail",trip$new_trip_distance_miles/ trip$prev_trip_duration_min, trip$check_mi_per_min)

trip$tripdur = ifelse(trip$new_mi_per_min > 1.25 & trip$mode_name=="Rail",trip$new_trip_distance_miles/1.25,trip$tripdur)

# Recalculate speed to check none is > 75 mph
trip$check_mi_per_min <- ifelse(trip$mode_name=="Rail",trip$new_trip_distance_miles/trip$tripdur, trip$check_mi_per_min)

# Add in loop trips (distance = 0, trip duration > 0) 
# using mean of non-loop trips 0.4527875 mi/min = 27.1 mph

mean_rail_speed <- mean(trip$check_mi_per_min[trip$mode_name=="Rail"],na.rm=TRUE)
mean_rail_speed

trip$looptrip <- ifelse(trip$trip_distance_miles==0 & trip$prev_trip_duration_min >0 & trip$mode_name=="Rail", "Loop", trip$looptrip)

trip$new_trip_distance_miles <- ifelse(trip$new_trip_distance_miles==0 & trip$trip_distance_miles==0 & trip$tripdur >0 & trip$mode_name=="Rail", trip$prev_trip_duration_min* mean_rail_speed, trip$new_trip_distance_miles)

# Recalculate mean rail speed with loop trips
trip$check_mi_per_min = trip$new_trip_distance_miles/trip$tripdur

mean_rail_speed2 <- mean(trip$check_mi_per_min[trip$mode_name=="Rail"],na.rm=TRUE)

# New mean rail speed 0.4543734 mi/min or 27.3 mph
mean_rail_speed2

############ Truck mode not available from travel survey #######
# Other terrestrial modes are not included in ITHIM calibration


# Distribution of Car-Driver trips by distance
# trips greater than 0 miles
trip$distance_gt0 <- ifelse(trip$new_trip_distance_miles >0, trip$new_trip_distance_miles,NA)

trip$dist_cat <- cut(trip$distance_gt0,breaks=c(0,1,3,5,1000),labels=c("<1","1-3","3-5","5+"), right=FALSE)

# Unweighted Analysis
# number of trips by distance category and mode
table(trip$dist_cat,trip$mode_name)

# Sum of distances by trip lengths
trip_dist_miles <-aggregate(trip$distance_gt0, by=list(trip$dist_cat, trip$mode_name),FUN="sum", na.rm=TRUE)

#Weighted Analysis
# Set up survey design 
library(survey)
tripsurvey <- svydesign(id=~sampno, weights=~exptcfperwgt, data=trip)
addmargins(svytable(~dist_cat+mode_name,design=tripsurvey))
svyby(~distance_gt0,~dist_cat+mode_name, tripsurvey, svytotal, na.rm="TRUE")


###################### Write out cleaned up trip file 
write.csv(trip, paste0("trip_cleaned",format(Sys.time(), "%Y-%m-%d"), ".csv"), row.names=FALSE)


######### Aggregate trip distance and time over persons by mode ########
# Create a person_id
trip$person_id <- paste0(trip$sampno,trip$perno)

pmt_min <-aggregate(trip[,c("new_trip_distance_miles","tripdur")],list(trip$person_id,trip$mode_name), FUN="sum")

#rename grouping variables
names(pmt_min)[names(pmt_min)=="Group.1"] <-"person_id"
names(pmt_min)[names(pmt_min)=="Group.2"] <-"mode_name"

# reshape from long to wide
# sort file on person ID
pmt_min <- pmt_min[order(pmt_min$person_id),]
pmt_min_wide <- reshape(pmt_min, timevar="mode_name", idvar= c("person_id"), direction="wide")

# Set missing to 0 and drop ferry and save plane modes
pmt_min_wide[is.na(pmt_min_wide)] <- 0
pmt_min_wide <- pmt_min_wide[,1:17]


############# Merge Trip File with Person file ######################

person <- merge(person,pmt_min_wide, by="person_id", all.x=TRUE)

# Assign no trips by mode to 0 miles and minutes
person[is.na(person)] <- 0
# replace original NA's 
person$gend[person$gend==0] <- NA

# Rename Car-driver and car-passenger without minus sign and sum
names(person)[names(person)=="tripdur.Car-driver"] <- "tripdur.Car_driver"
names(person)[names(person)=="tripdur.Car-passenger"] <- "tripdur.Car_passenger"
names(person)[names(person)=="new_trip_distance_miles.Car-driver"] <- "new_trip_distance_miles.Car_driver"
names(person)[names(person)=="new_trip_distance_miles.Car-passenger"] <- "new_trip_distance_miles.Car_passenger"


############### Item 1  ############################
# List of files/variables

#### Calculated weighted means, SEs, and CV
# Set up survey design 
library(survey)
survey <- svydesign(id=~sampno, weights=~expperwgt, data=person)

##################### Item 1 - min/p/d by mode #########################

wt_n <- tapply(person$expperwgt, person$megaregion_name, "sum")

# Trip Duration Mean, SE, CV
loop1 <- function( vars){ svyby( as.formula( paste0( "~tripdur." , vars ) ) , as.formula( paste("~megaregion_name")), design=survey, svymean, vartype=c("se","cv") ) }

# Unweighted Cases
loop2 <- function( vars){ svyby( as.formula( paste0( "~tripdur." , vars ) ) , as.formula( paste("~megaregion_name")), design=survey, unwtd.count, keep.var=FALSE ) }

# Make list of variables - Plane is place holder for Truck
flist <- c( "Bike" , "Walk", "Car_driver", "Car_passenger", "Bus", "Rail", "Motorcycle", "Plane")

# Apply svy command formula
out1 <- lapply( flist , loop1)
out2 <- lapply( flist , loop2)

# combine Unweighted Obs with mean, se, and cv for a mode
# add modes to a single mnaster file
# Initialize out file
item1 <- NULL

############## Begin loop - Concatenate files by mode ###################
for(i in 1:length(flist)){
  
  mvar <- as.data.frame(out1[i])
  mvar$mode <- flist[i]
  mvar$mode_code <- i 
  mobs <- as.data.frame(out2[i])
  
  modedat <- cbind(mvar,mobs,wt_n)
  colnames(modedat)[2] <- "item_result"
  colnames(modedat)[8] <- "unwt_n"
  item1 <- rbind(item1,modedat)
}

############################# End loop ################################

# Replace Plan mode with NAs
item1$item_result[item1$mode_code==8] <- NA
item1$se[item1$mode_code==8] <- NA
item1$cv[item1$mode_code==8] <- NA
item1$mode[item1$mode_code==8] <- "Truck"

# reassign geotype_code
item1$geotype_code[item1$megaregion_name == "San Diego"] <- "01"
item1$geotype_code[item1$megaregion_name =="Southern California"] <- "02"
item1$geotype_code[item1$megaregion_name == "Central Coast"] <- "03"
item1$geotype_code[item1$megaregion_name == "San Joaquin Valley"] <- "04"
item1$geotype_code[item1$megaregion_name == "Bay Area"] <- "05"
item1$geotype_code[item1$megaregion_name == "Sacramento Area"] <- "06"
item1$geotype_code[item1$megaregion_name == "Other"] <- "07"

# add fields for calibration sheet
item1$query_id <- 1
item1$scenario_id <- 0
item1$item_id <- 1
item1$item_name <- "Per capita mean daily travel time"
item1$units <- "min/person/d"
item1$urbrur <- 1
item1$report_year <- "2012"
item1$geotype <- "megaregion"
item1$geotype_name <- item1$megaregion_name
item1$strata_type <- "Race"
item1$strata <- "All Races"
item1$strata_code <- NA
item1$age_group <- "All Ages"
item1$sex <- "All"
item1$Date <- today
item1$source <- "CHTS2012"
          
# reorder variables
item1 <-item1[,c("query_id", "scenario_id", "item_id", "item_name", "units", "urbrur","report_year", "geotype", "geotype_name", "geotype_code", "mode", "mode_code", "strata_type", "strata", "strata_code", "age_group", "sex", "unwt_n", "wt_n", "item_result", "se", "cv", "Date", "source")]
             
# sort by geotype_code and mode
item1 <- item1[order(item1$geotype_code,item1$mode_code),]
             
# Write out datafile
write.csv(item1,"item1.csv", row.names=FALSE)

##################### Item 3 - mi/p/d ##################################

#### Calculated weighted means, SEs, and CV

# Trip Distance Mean, SE, CV
loop1 <- function( vars){ svyby( as.formula( paste0( "~new_trip_distance_miles." , vars ) ) , as.formula( paste("~megaregion_name")), design=survey, svymean, vartype=c("se","cv") ) }

# Unweighted Cases
loop2 <- function( vars){ svyby( as.formula( paste0( "~new_trip_distance_miles." , vars ) ) , as.formula( paste("~megaregion_name")), design=survey, unwtd.count, keep.var=FALSE ) }

# Make list of variables 
flist <- c( "Bike" , "Walk", "Car_driver", "Car_passenger", "Bus", "Rail", "Motorcycle", "Plane")

# Apply svy command formula
out1 <- lapply( flist , loop1)
out2 <- lapply( flist , loop2)

# combine Unweighted Obs with mean, se, and cv for a mode
# add modes to a single mnaster file
# Initialize out file
item3 <- NULL

############## Begin loop - Concatenate files by mode ###################
for(i in 1:length(flist)){
  
  mvar <- as.data.frame(out1[i])
  mvar$mode <- flist[i]
  mvar$mode_code <- i 
  mobs <- as.data.frame(out2[i])
  
  modedat <- cbind(mvar,mobs,wt_n)
  colnames(modedat)[2] <- "item_result"
  colnames(modedat)[8] <- "unwt_n"
  item3 <- rbind(item3,modedat)
}

############################# End loop ################################

# Replace Other mode with NAs
item3$item_result[item3$mode_code==8] <- NA
item3$se[item3$mode_code==8] <- NA
item3$cv[item3$mode_code==8] <- NA
item3$mode[item3$mode_code==8] <- "Truck"

# reassign geotype_code
item3$geotype_code[item3$megaregion_name == "San Diego"] <- "01"
item3$geotype_code[item3$megaregion_name =="Southern California"] <- "02"
item3$geotype_code[item3$megaregion_name == "Central Coast"] <- "03"
item3$geotype_code[item3$megaregion_name == "San Joaquin Valley"] <- "04"
item3$geotype_code[item3$megaregion_name == "Bay Area"] <- "05"
item3$geotype_code[item3$megaregion_name == "Sacramento Area"] <- "06"
item3$geotype_code[item3$megaregion_name == "Other"] <- "07"

# add fields for calibration sheet
item3$query_id <- 1
item3$scenario_id <- 0
item3$item_id <- 3
item3$item_name <- "Per capita mean daily travel distance"
item3$units <- "miles/person/d"
item3$urbrur <- 1
item3$report_year <- "2012"
item3$geotype <- "megaregion"
item3$geotype_name <- item3$megaregion_name
item3$strata_type <- "Race"
item3$strata <- "All Races"
item3$strata_code <- NA
item3$age_group <- "All Ages"
item3$sex <- "All"
item3$Date <- today
item3$source <- "CHTS2012"
          
# reorder variables
item3 <-item3[,c("query_id", "scenario_id", "item_id", "item_name", "units", "urbrur","report_year", "geotype", "geotype_name", "geotype_code", "mode", "mode_code", "strata_type", "strata", "strata_code", "age_group", "sex", "unwt_n", "wt_n", "item_result", "se", "cv", "Date", "source")]
             
# sort by geotype_code and mode
item3 <- item3[order(item3$geotype_code,item3$mode_code),]
             
# Write out datafile
write.csv(item3,"item3.csv", row.names=FALSE)

################## Item 2 - ratio of bike & walk times by mode ######

#### Calculated weighted means, SEs, and CV
wt_n <- aggregate(person$expperwgt~person$megaregion_name+person$age8cat+person$gend, FUN="sum")
names(wt_n)[names(wt_n)=="person$megaregion_name"] <- "megaregion_name"
names(wt_n)[names(wt_n)=="person$age8cat"] <- "age8cat"
names(wt_n)[names(wt_n)=="person$gend"] <- "gend"
names(wt_n)[names(wt_n)=="person$expperwgt"] <- "wt_n"

# Trip Duration Mean, SE, CV
loop1 <- function( vars){ svyby( as.formula( paste0( "~tripdur." , vars ) ) , as.formula( paste("~megaregion_name+age8cat+gend")), design=survey, svymean, vartype=c("se","cv") ) }

# Unweighted Cases
loop2 <- function( vars){ svyby( as.formula( paste0( "~tripdur." , vars ) ) , as.formula( paste("~megaregion_name+age8cat+gend")), design=survey, unwtd.count, keep.var=FALSE ) }

# Make list of variables
flist <- c( "Bike" , "Walk")

# Apply svy command formula
out1 <- lapply( flist , loop1)
out2 <- lapply( flist , loop2)

# combine Unweighted Obs with mean, se, and cv for a mode
# add modes to a single master file
# Initialize out file
item2 <- NULL

############## Begin loop - Concatenate files by mode ###################
for(i in 1:length(flist)){
  
  mvar <- as.data.frame(out1[i])
  mvar$mode <- flist[i]
  mvar$mode_code <- i 
  mobs <- as.data.frame(out2[i])
  
  modedat <- cbind(mvar,mobs,wt_n)
  colnames(modedat)[4] <- "item_result"
  colnames(modedat)[12] <- "unwt_n"
  item2 <- rbind(item2,modedat)
  
}
############################# End loop ################################

# recode geotype_code
item2$geotype_code[item2$megaregion_name == "San Diego"] <- "01"
item2$geotype_code[item2$megaregion_name =="Southern California"] <- "02"
item2$geotype_code[item2$megaregion_name == "Central Coast"] <- "03"
item2$geotype_code[item2$megaregion_name == "San Joaquin Valley"] <- "04"
item2$geotype_code[item2$megaregion_name == "Bay Area"] <- "05"
item2$geotype_code[item2$megaregion_name == "Sacramento Area"] <- "06"
item2$geotype_code[item2$megaregion_name == "Other"] <- "07"

item2$sex <- NA
item2$sex[item2$gend == 1] <- "M"
item2$sex[item2$gend == 2] <- "F"

# add fields for calibration sheet
item2$query_id <- 1
item2$scenario_id <- 0
item2$item_id <- 2
item2$item_name <- "Per capita mean daily travel time by mode"
item2$units <- "min/person/d"
item2$urbrur <- 1
item2$report_year <- "2012"
item2$geotype <- "megaregion"
item2$geotype_name <- item2$megaregion_name
item2$strata_type <- "Race"
item2$strata <- "All Races"
item2$strata_code <- NA
item2$age_group <- item2$age8cat
item2$Date <- today
item2$source <- "CHTS2012"
          
# reorder variables
item2 <-item2[,c("query_id", "scenario_id", "item_id", "item_name", "units", "urbrur","report_year", "geotype", "geotype_name", "geotype_code", "mode", "mode_code", "strata_type", "strata", "strata_code", "age_group", "sex", "unwt_n", "wt_n", "item_result", "se", "cv", "Date", "source")]

# Write out datafile
write.csv(item2,"item2_check.csv", row.names=FALSE)


# Subset item 1 for all ages combined and add to file
item1_all_age <- subset(item1, item1$mode == "Walk" | item1$mode == "Bike")

# Append to item2 and resort
item2 <- rbind(item2,item1_all_age)

         
# sort by geotype_code and mode
item2 <- item2[order(item2$geotype_code,item2$mode_code,item2$sex,item2$age_group),]

# subset item_result for females aged 15-29
f15_29 <- subset(item2, item2$age_group=="15-29" & item2$sex=="F")

# Keep variables of interest
f15_29 <- f15_29[,c("mode", "geotype_name", "item_result")]

# rename item result
names(f15_29)[names(f15_29) == "item_result"] <- "f15_29"

# merge back to item2
item2 <- merge(item2,f15_29, by= c("mode", "geotype_name"), all.x=TRUE)

# Create ratio
item2$bwratio <- item2$item_result/item2$f15_29

# rename item result
names(item2)[names(item2) == "item_result"] <- "min_person_day"
names(item2)[names(item2) == "bwratio"] <- "item_result"
item2$f15_29 <- NULL

# reorder variable list

# reorder variables
item2 <-item2[,c("query_id", "scenario_id", "item_id", "item_name", "units", "urbrur","report_year", "geotype", "geotype_name", "geotype_code", "mode", "mode_code", "strata_type", "strata", "strata_code", "age_group", "sex", "unwt_n", "wt_n", "item_result", "se", "cv", "Date", "source","min_person_day")]

# sort by geotype_code and mode
item2 <- item2[order(item2$geotype_name,item2$mode,item2$sex,item2$age_group),]

             
# Write out datafile
write.csv(item2,"item2.csv", row.names=FALSE)



